@@ -111,7 +111,7 @@ def test_superstaq_client_args(api_version: str) -> None:
         "ibmq_token": "ibm_cloud_token",
     }
 
-    with pytest.raises(ValueError, match="must be either 'ibm_cloud' or 'ibm_quantum_platform'"):
+    with pytest.raises(ValueError, match=r"must be either 'ibm_cloud' or 'ibm_quantum_platform'"):
         _ = client_version(
             client_name="general-superstaq",
             remote_host="http://example.com",
@@ -120,7 +120,7 @@ def test_superstaq_client_args(api_version: str) -> None:
             ibmq_channel="foo",
         )
 
-    with pytest.raises(ValueError, match="Instead, use 'ibm_quantum_platform'"):
+    with pytest.raises(ValueError, match=r"Instead, use 'ibm_quantum_platform'"):
         _ = client_version(
             client_name="general-superstaq",
             remote_host="http://example.com",
@@ -153,12 +153,12 @@ def test_warning_from_server(client_name: str, request: pytest.FixtureRequest) -
 
     with mock.patch("requests.Session.get", ok=True) as mock_get:
         mock_get.return_value.json = lambda: {"abc": 123, "warnings": [warning]}
-        with pytest.warns(gss.SuperstaqWarning, match="WARNING!"):
+        with pytest.warns(gss.SuperstaqWarning, match=r"WARNING!"):
             assert client.get_request("/endpoint") == {"abc": 123}
 
     with mock.patch("requests.Session.post", ok=True) as mock_post:
         mock_post.return_value.json = lambda: {"abc": 123, "warnings": [warning, warning]}
-        with pytest.warns(gss.SuperstaqWarning, match="WARNING!"):
+        with pytest.warns(gss.SuperstaqWarning, match=r"WARNING!"):
             assert client.post_request("/endpoint", {}) == {"abc": 123}
 
 
@@ -166,7 +166,7 @@ def test_warning_from_server(client_name: str, request: pytest.FixtureRequest) -
 @pytest.mark.parametrize("invalid_url", ["http://", "ftp:s//foo", "http:/:42"])
 def test_superstaq_client_invalid_remote_host_netloc(api_version: str, invalid_url: str) -> None:
     client_version = CLIENT_VERSION[api_version]
-    with pytest.raises(AssertionError, match="Specified network location"):
+    with pytest.raises(AssertionError, match=r"Specified network location"):
         _ = client_version(
             client_name="general-superstaq",
             remote_host=invalid_url,
@@ -182,7 +182,7 @@ def test_superstaq_client_invalid_remote_host_netloc(api_version: str, invalid_u
 )
 def test_superstaq_client_invalid_remote_host_protocol(api_version: str, invalid_url: str) -> None:
     client_version = CLIENT_VERSION[api_version]
-    with pytest.raises(AssertionError, match="Specified URL protocol"):
+    with pytest.raises(AssertionError, match=r"Specified URL protocol"):
         _ = client_version(
             client_name="general-superstaq",
             remote_host=invalid_url,
@@ -194,14 +194,14 @@ def test_superstaq_client_invalid_remote_host_protocol(api_version: str, invalid
 @pytest.mark.parametrize("api_version", ["v0.2.0", "v0.3.0"])
 def test_superstaq_client_invalid_api_version(api_version: str) -> None:
     client_version = CLIENT_VERSION[api_version]
-    with pytest.raises(AssertionError, match="are accepted"):
+    with pytest.raises(AssertionError, match=r"are accepted"):
         _ = client_version(
             client_name="general-superstaq",
             remote_host="http://example.com",
             api_key="a",
             api_version="v0.0",
         )
-    with pytest.raises(AssertionError, match="0.0"):
+    with pytest.raises(AssertionError, match=r"0.0"):
         _ = client_version(
             client_name="general-superstaq",
             remote_host="http://example.com",
@@ -213,7 +213,7 @@ def test_superstaq_client_invalid_api_version(api_version: str) -> None:
 @pytest.mark.parametrize("api_version", ["v0.2.0", "v0.3.0"])
 def test_superstaq_client_time_travel(api_version: str) -> None:
     client_version = CLIENT_VERSION[api_version]
-    with pytest.raises(AssertionError, match="time machine"):
+    with pytest.raises(AssertionError, match=r"time machine"):
         _ = client_version(
             client_name="general-superstaq",
             remote_host="http://example.com",
@@ -305,7 +305,7 @@ def test_superstaq_client_needs_accept_terms_of_use(
 
         with mock.patch("builtins.input"):
             with pytest.raises(
-                gss.SuperstaqServerException, match="You'll need to accept the Terms of Use"
+                gss.SuperstaqServerException, match=r"You'll need to accept the Terms of Use"
             ):
                 client.get_balance()
             assert capsys.readouterr().out == "YES response required to proceed\n"
@@ -335,7 +335,7 @@ def test_superstaq_client_validate_email_error(
     mock_post.return_value.json.return_value = "You must validate your registered email."
 
     with pytest.raises(
-        gss.SuperstaqServerException, match="You must validate your registered email."
+        gss.SuperstaqServerException, match=r"You must validate your registered email."
     ):
         _ = client.create_job({"cirq_circuits": "World"}, target="ss_example_qpu")
 
@@ -450,7 +450,7 @@ def test_superstaq_client_create_job_unauthorized(
     mock_post.return_value.ok = False
     mock_post.return_value.status_code = requests.codes.unauthorized
 
-    with pytest.raises(gss.SuperstaqServerException, match="Not authorized"):
+    with pytest.raises(gss.SuperstaqServerException, match=r"Not authorized"):
         _ = client.create_job({"cirq_circuits": "World"}, target="ss_example_qpu")
 
 
@@ -482,7 +482,7 @@ def test_superstaq_client_create_job_not_retriable(
     mock_post.return_value.ok = False
     mock_post.return_value.status_code = requests.codes.not_implemented
 
-    with pytest.raises(gss.SuperstaqServerException, match="Status code: 501"):
+    with pytest.raises(gss.SuperstaqServerException, match=r"Status code: 501"):
         _ = client.create_job({"cirq_circuits": "World"}, target="ss_example_qpu")
 
 
@@ -552,7 +552,7 @@ def test_superstaq_client_create_job_invalid_json(
 
     with (
         mock.patch("requests.Session.post", return_value=response),
-        pytest.raises(gss.SuperstaqServerException, match="invalid/json"),
+        pytest.raises(gss.SuperstaqServerException, match=r"invalid/json"),
     ):
         _ = client.create_job({"qiskit_circuits": "World"}, target="ss_example_qpu")
 
@@ -573,7 +573,7 @@ def test_superstaq_client_create_job_dont_retry_on_timeout(
 
     with (
         mock.patch("requests.Session.post", return_value=response),
-        pytest.raises(gss.SuperstaqServerException, match="timed out"),
+        pytest.raises(gss.SuperstaqServerException, match=r"timed out"),
     ):
         _ = client.create_job({"cirq_circuits": "World"}, target="ss_example_qpu")
 
@@ -617,7 +617,7 @@ def test_superstaq_client_create_job_json(
         "num_circuits": 1,
     }
 
-    with pytest.raises(gss.SuperstaqServerException, match="Status code: 400"):
+    with pytest.raises(gss.SuperstaqServerException, match=r"Status code: 400"):
         _ = client.create_job(
             serialized_circuits={"cirq_circuits": "World"},
             repetitions=200,
@@ -675,6 +675,7 @@ def test_superstaq_client_fetch_jobs(
                 "final_logical_to_physicals": [{0: 0}],
                 "logical_qubits": ["0"],
                 "physical_qubits": ["0"],
+                "tags": [],
             }
         }
         mock_get.return_value.ok = True
@@ -811,10 +812,10 @@ def test_update_user_balance(
 
 
 def test_update_user_balance_invalid_v3(client_v3: gss.superstaq_client._SuperstaqClientV3) -> None:
-    with pytest.raises(ValueError, match="user email"):
+    with pytest.raises(ValueError, match=r"user email"):
         client_v3.update_user_balance({"balance": 5.00})
 
-    with pytest.raises(ValueError, match="new balance"):
+    with pytest.raises(ValueError, match=r"new balance"):
         client_v3.update_user_balance({"email": "test@email.com"})
 
 
@@ -858,10 +859,10 @@ def test_update_user_role(
 
 
 def test_update_user_role_invalid_v3(client_v3: gss.superstaq_client._SuperstaqClientV3) -> None:
-    with pytest.raises(ValueError, match="user email"):
+    with pytest.raises(ValueError, match=r"user email"):
         client_v3.update_user_role({"role": "genius"})
 
-    with pytest.raises(ValueError, match="new role"):
+    with pytest.raises(ValueError, match=r"new role"):
         client_v3.update_user_role({"email": "test@email.com"})
 
 
@@ -880,7 +881,7 @@ def test_superstaq_client_resource_estimate(
         mock_post.assert_called_once()
         assert mock_post.call_args[0][0] == f"http://example.com/{api_version}/resource_estimate"
     else:
-        with pytest.raises(NotImplementedError, match="resource_estimate is not implemented"):
+        with pytest.raises(NotImplementedError, match=r"resource_estimate is not implemented"):
             client.resource_estimate({"Hello": "1", "World": "2"})
 
 
@@ -1054,7 +1055,7 @@ def test_superstaq_client_fetch_jobs_unauthorized(
         mock_call.return_value.ok = False
         mock_call.return_value.status_code = requests.codes.unauthorized
 
-        with pytest.raises(gss.SuperstaqServerException, match="Not authorized"):
+        with pytest.raises(gss.SuperstaqServerException, match=r"Not authorized"):
             _ = client.fetch_jobs([job_id])
 
 
@@ -1100,7 +1101,7 @@ def test_superstaq_client_fetch_jobs_not_retriable(
         mock_call.return_value.ok = False
         mock_call.return_value.status_code = requests.codes.bad_request
 
-        with pytest.raises(gss.SuperstaqServerException, match="Status code: 400"):
+        with pytest.raises(gss.SuperstaqServerException, match=r"Status code: 400"):
             _ = client.fetch_jobs([job_id])
 
 
@@ -1152,7 +1153,7 @@ def test_superstaq_client_cancel_jobs_unauthorized(
         mock_call.return_value.ok = False
         mock_call.return_value.status_code = requests.codes.unauthorized
 
-        with pytest.raises(gss.SuperstaqServerException, match="Not authorized"):
+        with pytest.raises(gss.SuperstaqServerException, match=r"Not authorized"):
             _ = client.cancel_jobs([job_id])
 
 
@@ -1198,7 +1199,7 @@ def test_superstaq_client_get_cancel_jobs_retriable(
         mock_call.return_value.ok = False
         mock_call.return_value.status_code = requests.codes.bad_request
 
-        with pytest.raises(gss.SuperstaqServerException, match="Status code: 400"):
+        with pytest.raises(gss.SuperstaqServerException, match=r"Status code: 400"):
             _ = client.cancel_jobs([job_id], cq_token=1)
 
 
@@ -1246,7 +1247,7 @@ def test_superstaq_client_aqt_compile(
         mock_post.assert_called_once()
         assert mock_post.call_args[0][0] == f"http://example.com/{api_version}/aqt_compile"
     else:
-        with pytest.raises(DeprecationWarning, match="`aqt_compile` is deprecated"):
+        with pytest.raises(DeprecationWarning, match=r"`aqt_compile` is deprecated"):
             client.aqt_compile({"Hello": "1", "World": "2"})
 
 
@@ -1265,7 +1266,7 @@ def test_superstaq_client_qscout_compile(
         mock_post.assert_called_once()
         assert mock_post.call_args[0][0] == f"http://example.com/{api_version}/qscout_compile"
     else:
-        with pytest.raises(DeprecationWarning, match="`qscout_compile` is deprecated"):
+        with pytest.raises(DeprecationWarning, match=r"`qscout_compile` is deprecated"):
             client.qscout_compile({"Hello": "1", "World": "2"})
 
 
@@ -1285,14 +1286,14 @@ def test_superstaq_client_compile_v2(
 def test_superstaq_client_compile_v3_multi_circuit_types(
     client_v3: gss.superstaq_client._SuperstaqClientV3,
 ) -> None:
-    with pytest.raises(RuntimeError, match="multiple circuit types"):
+    with pytest.raises(RuntimeError, match=r"multiple circuit types"):
         client_v3.compile({"cirq_circuits": "Hello", "qiskit_circuits": "World"})
 
 
 def test_superstaq_client_compile_v3__type_not_found(
     client_v3: gss.superstaq_client._SuperstaqClientV3,
 ) -> None:
-    with pytest.raises(RuntimeError, match="No recognized circuits found."):
+    with pytest.raises(RuntimeError, match=r"No recognized circuits found."):
         client_v3.compile({"qasm_circuits": "Hello"})
 
 
@@ -1567,7 +1568,7 @@ def test_superstaq_client_submit_qubo(
             verify=False,
         )
     else:
-        with pytest.raises(NotImplementedError, match="submit_qubo is not implemented"):
+        with pytest.raises(NotImplementedError, match=r"submit_qubo is not implemented"):
             client.submit_qubo(
                 example_qubo,
                 target,
@@ -1578,6 +1579,34 @@ def test_superstaq_client_submit_qubo(
             )
 
 
+@pytest.mark.parametrize("client_name", ["client_v2", "client_v3"])
+@mock.patch("requests.Session.post")
+def test_superstaq_client_atom_picture(
+    mock_post: mock.MagicMock,
+    client_name: str,
+    request: pytest.FixtureRequest,
+) -> None:
+    client = request.getfixturevalue(client_name)
+    api_version = client.api_version
+    bitmap_2d = [[0, 1, 2], [0, 0, 0], [2, 1, 1]]
+
+    if api_version == "v0.2.0":
+        client.submit_atom_picture(bitmap_2d)
+
+        expected_json = {
+            "bitmap_1d_array": [0, 1, 2, 0, 0, 0, 2, 1, 1],
+        }
+        mock_post.assert_called_with(
+            f"http://example.com/{api_version}/atom_picture",
+            headers=EXPECTED_HEADERS[api_version],
+            json=expected_json,
+            verify=False,
+        )
+    else:
+        with pytest.raises(NotImplementedError, match=r"atom_picture is not implemented"):
+            client.submit_atom_picture(bitmap_2d)
+
+
 @pytest.mark.parametrize("client_name", ["client_v2", "client_v3"])
 @mock.patch("requests.Session.post")
 def test_superstaq_client_supercheq(
@@ -1604,7 +1633,7 @@ def test_superstaq_client_supercheq(
             verify=False,
         )
     else:
-        with pytest.raises(NotImplementedError, match="supercheq is not implemented"):
+        with pytest.raises(NotImplementedError, match=r"supercheq is not implemented"):
             client.supercheq([[0]], 1, 1, "cirq_circuits")
 
 
@@ -1661,7 +1690,7 @@ def test_superstaq_client_aces(
             verify=False,
         )
     else:
-        with pytest.raises(NotImplementedError, match="submit_aces is not implemented"):
+        with pytest.raises(NotImplementedError, match=r"submit_aces is not implemented"):
             client.submit_aces(
                 target="ss_unconstrained_simulator",
                 qubits=[0, 1],
@@ -1676,7 +1705,7 @@ def test_superstaq_client_aces(
                 noise={"type": "symmetric_depolarize", "params": (0.01,)},
             )
 
-        with pytest.raises(NotImplementedError, match="process_aces is not implemented"):
+        with pytest.raises(NotImplementedError, match=r"process_aces is not implemented"):
             client.process_aces(uuid.UUID(int=0))
 
 
@@ -1728,7 +1757,7 @@ def test_superstaq_client_cb(
             verify=False,
         )
     else:
-        with pytest.raises(NotImplementedError, match="submit_cb is not implemented"):
+        with pytest.raises(NotImplementedError, match=r"submit_cb is not implemented"):
             client.submit_cb(
                 target="ss_unconstrained_simulator",
                 shots=100,
@@ -1740,7 +1769,7 @@ def test_superstaq_client_cb(
                 noise={"type": "symmetric_depolarize", "params": (0.01,)},
             )
 
-        with pytest.raises(NotImplementedError, match="process_cb is not implemented"):
+        with pytest.raises(NotImplementedError, match=r"process_cb is not implemented"):
             client.process_cb(uuid.UUID(int=0), "count")
 
 
@@ -1793,10 +1822,10 @@ def test_superstaq_client_dfe(
             verify=False,
         )
 
-        with pytest.raises(ValueError, match="must contain exactly two job ids"):
+        with pytest.raises(ValueError, match=r"must contain exactly two job ids"):
             client.process_dfe(["1", "2", "3"])
     else:
-        with pytest.raises(NotImplementedError, match="submit_dfe is not implemented"):
+        with pytest.raises(NotImplementedError, match=r"submit_dfe is not implemented"):
             client.submit_dfe(
                 circuit_1={"Hello": "World"},
                 target_1="ss_example_qpu",
@@ -1807,7 +1836,7 @@ def test_superstaq_client_dfe(
                 lifespan=10,
             )
 
-        with pytest.raises(NotImplementedError, match="process_dfe is not implemented"):
+        with pytest.raises(NotImplementedError, match=r"process_dfe is not implemented"):
             client.process_dfe([uuid.UUID(int=0)])
 
 
@@ -1966,7 +1995,7 @@ def test_read_ibm_credentials() -> None:
         # fail because multiple accounts found with none marked as default
         with (
             pytest.raises(
-                ValueError, match="Multiple accounts found but none are marked as default."
+                ValueError, match=r"Multiple accounts found but none are marked as default."
             ),
             mock.patch(
                 "builtins.open", mock.mock_open(read_data=json.dumps(multiple_none_default_account))
@@ -1976,21 +2005,23 @@ def test_read_ibm_credentials() -> None:
 
         # fail because provided name is not an account in the config
         with (
-            pytest.raises(KeyError, match="No account credentials saved under the name 'bad_key'"),
+            pytest.raises(KeyError, match=r"No account credentials saved under the name 'bad_key'"),
             mock.patch("builtins.open", mock.mock_open(read_data=json.dumps(credentials))),
         ):
             gss.superstaq_client.read_ibm_credentials("bad_key")
 
         # fail with missing token field in config
         with (
-            pytest.raises(KeyError, match="`token` and/or `channel` keys missing from credentials"),
+            pytest.raises(
+                KeyError, match=r"`token` and/or `channel` keys missing from credentials"
+            ),
             mock.patch("builtins.open", mock.mock_open(read_data=json.dumps(bad_credentials))),
         ):
             gss.superstaq_client.read_ibm_credentials(None)
     #
     # fail to find credentials file
     with (
-        pytest.raises(FileNotFoundError, match="The `qiskit-ibm.json` file was not found in"),
+        pytest.raises(FileNotFoundError, match=r"The `qiskit-ibm.json` file was not found in"),
         mock.patch("pathlib.Path.is_file", return_value=False),
     ):
         gss.superstaq_client.read_ibm_credentials(None)
@@ -2011,7 +2042,7 @@ def test_find_api_key() -> None:
 
     # fail to find an API key :(
     with (
-        pytest.raises(EnvironmentError, match="Superstaq API key not specified and not found."),
+        pytest.raises(EnvironmentError, match=r"Superstaq API key not specified and not found."),
         mock.patch.dict(os.environ, SUPERSTAQ_API_KEY=""),
         mock.patch("pathlib.Path.is_file", return_value=False),
     ):
@@ -2115,7 +2146,7 @@ def test_get_user_info_query(
 
 
 def test_get_user_info_v3_fail(client_v3: gss.superstaq_client._SuperstaqClientV3) -> None:
-    with pytest.raises(TypeError, match="Superstaq API v0.3.0 uses UUID"):
+    with pytest.raises(TypeError, match=r"Superstaq API v0.3.0 uses UUID"):
         client_v3.get_user_info(user_id=42)
 
 
@@ -2199,7 +2230,7 @@ def test_get_user_info_empty_response(
 
     with pytest.raises(
         gss.SuperstaqServerException,
-        match=("Something went wrong. The server has returned an empty response."),
+        match=(r"Something went wrong. The server has returned an empty response."),
     ):
         client.get_user_info()
 
