@@ -9,10 +9,10 @@ import general_superstaq as gss
 
 
 def test_validate_target() -> None:
-    with pytest.raises(ValueError, match="does not have a valid string format"):
+    with pytest.raises(ValueError, match=r"does not have a valid string format"):
         gss.validation.validate_target("invalid_target")
 
-    with pytest.raises(ValueError, match="does not have a valid target device type"):
+    with pytest.raises(ValueError, match=r"does not have a valid target device type"):
         gss.validation.validate_target("ibmq_invalid_device")
 
 
@@ -37,7 +37,7 @@ def test_validate_integer_param() -> None:
     for input_value in invalid_values:
         with pytest.raises(
             ValueError,
-            match="is less than the minimum",
+            match=r"is less than the minimum",
         ):
             gss.validation.validate_integer_param(input_value)
 
@@ -53,11 +53,11 @@ def test_validate_noise_type() -> None:
         gss.validation.validate_noise_type(input_value, 1)
 
     with pytest.raises(
-        ValueError, match="`params` must be a sequence in the dict if `type` is in the dict."
+        ValueError, match=r"`params` must be a sequence in the dict if `type` is in the dict."
     ):
         gss.validation.validate_noise_type({"type": "test"}, 1)
 
-    with pytest.raises(ValueError, match="is not a valid channel."):
+    with pytest.raises(ValueError, match=r"is not a valid channel."):
         gss.validation.validate_noise_type({"type": "other_channel", "params": (0.1,)}, 1)
 
     with pytest.raises(ValueError, match='for "bit_flip", and "phase_flip"'):
@@ -72,20 +72,52 @@ def test_validate_noise_type() -> None:
         )
 
 
+def test_validate_bitmap() -> None:
+    with pytest.raises(ValueError, match=r"contain the integers 0, 1, or 2"):
+        gss.validation.validate_bitmap([[3, 0], [1, 0]])
+    rng = np.random.default_rng()
+    with pytest.raises(TypeError, match=r"must be a 2D"):
+        gss.validation.validate_bitmap(rng.integers(0, high=3, size=(2, 2, 2)))
+    with pytest.raises(TypeError, match=r"must be a square 2D"):
+        gss.validation.validate_bitmap(rng.integers(0, high=3, size=(3, 2)))
+
+    valid_bitmaps = (
+        [
+            [2, 1, 0],
+            [1, 2, 1],
+            [0, 1, 2],
+        ],
+        (
+            (1, 0, 1, 2),
+            (0, 1, 0, 1),
+            (1, 2, 1, 0),
+            (0, 1, 0, 1),
+        ),
+        [
+            (1, 1, 2),
+            (0, 0, 1),
+            (1, 0, 2),
+        ],
+        np.eye(3, dtype=int),
+    )
+    for valid_bitmap in valid_bitmaps:
+        gss.validation.validate_bitmap(valid_bitmap)
+
+
 def test_validate_qubo() -> None:
-    with pytest.raises(ValueError, match="QUBOs must be"):
+    with pytest.raises(TypeError, match=r"QUBOs must be"):
         gss.validation.validate_qubo("not-a-dict")
 
-    with pytest.raises(ValueError, match="not a valid key"):
+    with pytest.raises(TypeError, match=r"not a valid key"):
         gss.validation.validate_qubo({"abc": 123})
 
-    with pytest.raises(ValueError, match="must be real numbers"):
+    with pytest.raises(TypeError, match=r"must be real numbers"):
         gss.validation.validate_qubo({(1, 2): 12 + 3j})
 
-    with pytest.raises(ValueError, match="must be real numbers"):
+    with pytest.raises(TypeError, match=r"must be real numbers"):
         gss.validation.validate_qubo({(1, 2): "abc"})
 
-    with pytest.raises(ValueError, match="must be quadratic"):
+    with pytest.raises(ValueError, match=r"must be quadratic"):
         gss.validation.validate_qubo({(1, 2, 3): 123})
 
     gss.validation.validate_qubo({(1,): 1.2, (2,): 2.3, (1, 2): -3.4})
